@@ -136,7 +136,7 @@ hobj <- .Fortran("caws",as.double(y),
                        as.double(0.25),
                        double(prod(dlw)),
                        as.double(wghts),
-                       PACKAGE="aws",DUP=TRUE)[c("bi","ai")]
+                       PACKAGE="aws")[c("bi","ai")]
 hobj$theta <- hobj$ai/hobj$bi
 dim(hobj$theta) <- dim(hobj$bi) <- dy
 #
@@ -176,7 +176,6 @@ zobj <- .Fortran("segment",as.double(y),
                        as.double(0.25),
                        double(prod(dlw)),
                        as.double(wghts),
-                       pvalues=double(n),# array for pvalues
                        as.integer(segment),# previous segmentation array 
                        segment=as.integer(segment),# new array for segment (-1,0,1)
                        as.double(beta),
@@ -184,15 +183,14 @@ zobj <- .Fortran("segment",as.double(y),
                        as.double(ext),
                        as.double(fov),
                        varest=as.double(varest),
-                       PACKAGE="aws")[c("fix","bi","bi0","bi2","vred","pvalues",
+                       PACKAGE="aws")[c("fix","bi","bi0","bi2","vred",
                        "segment","theta","gi","hakt","varest")]
 vred[!fix]<-zobj$vred[!fix]
 if(hakt>n1/2) zobj$bi0 <- rep(max(zobj$bi),n)
-pvalues <- zobj$pvalues
 segment <- zobj$segment
 varest <- zobj$varest
 fix <- zobj$fix
-dim(zobj$theta) <- dim(zobj$gi) <- dim(pvalues) <- dim(segment) <- dim(fix) <- dim(zobj$bi) <- dy
+dim(zobj$theta) <- dim(zobj$gi) <- dim(segment) <- dim(fix) <- dim(zobj$bi) <- dy
 if(graph){
 #
 #     Display intermediate results if graph == TRUE
